@@ -1,5 +1,5 @@
 /*******************************************************************************
- *  Copyright (c) 2000, 2021 IBM Corporation and others.
+ *  Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  *  This program and the accompanying materials
  *  are made available under the terms of the Eclipse Public License 2.0
@@ -152,6 +152,15 @@ public class JavaProjectHelper {
 		return isCompatible(16);
 	}
 
+	/**
+	 * Returns if the currently running VM is version compatible with Java 19
+	 *
+	 * @return <code>true</code> if a Java 19 (or greater) VM is running <code>false</code> otherwise
+	 */
+	public static boolean isJava19_Compatible() {
+		return isCompatible(19);
+	}
+
 	/**
 	 * Returns if the current running system is compatible with the given Java minor version
 	 *
