@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2021 IBM Corporation and others.
+ * Copyright (c) 2000, 2022 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -42,6 +42,7 @@ import org.eclipse.jdt.debug.tests.breakpoints.RecordBreakpointTests;
 import org.eclipse.jdt.debug.tests.breakpoints.RunToLineTests;
 import org.eclipse.jdt.debug.tests.breakpoints.SpecialExceptionBreakpointTests;
 import org.eclipse.jdt.debug.tests.breakpoints.SuspendVMBreakpointsTests;
+import org.eclipse.jdt.debug.tests.breakpoints.SuspendVMConditionalBreakpointsTests;
 import org.eclipse.jdt.debug.tests.breakpoints.TargetPatternBreakpointTests;
 import org.eclipse.jdt.debug.tests.breakpoints.TestToggleBreakpointsTarget;
 import org.eclipse.jdt.debug.tests.breakpoints.TestToggleBreakpointsTarget8;
@@ -53,6 +54,7 @@ import org.eclipse.jdt.debug.tests.breakpoints.WatchpointTests;
 import org.eclipse.jdt.debug.tests.connectors.MultipleConnectionsTest;
 import org.eclipse.jdt.debug.tests.console.ConsoleTerminateAllActionTests;
 import org.eclipse.jdt.debug.tests.console.IOConsoleTests;
+import org.eclipse.jdt.debug.tests.console.JavaDebugStackTraceConsoleTest;
 import org.eclipse.jdt.debug.tests.console.JavaStackTraceConsoleTest;
 import org.eclipse.jdt.debug.tests.core.AlternateStratumTests;
 import org.eclipse.jdt.debug.tests.core.ArgumentTests;
@@ -259,6 +261,7 @@ public class AutomatedSuite extends DebugSuite {
 		addTest(new TestSuite(ConsoleInputTests.class));
 		addTest(new TestSuite(LineTrackerTests.class));
 		addTest(new TestSuite(JavaStackTraceConsoleTest.class));
+		addTest(new TestSuite(JavaDebugStackTraceConsoleTest.class));
 		addTest(new TestSuite(IOConsoleTests.class));
 		addTest(new TestSuite(ConsoleTerminateAllActionTests.class));
 
@@ -340,7 +343,7 @@ public class AutomatedSuite extends DebugSuite {
 			addTest(new TestSuite(LambdaVariableTest.class));
 		}
 		//addTest(EvalTestSuite.suite());
-		if (JavaProjectHelper.isJava9Compatible()) {
+		if (JavaProjectHelper.isJava9Compatible() && !JavaProjectHelper.isJava19_Compatible()) {
 			addTest(new TestSuite(Java9Tests.class));
 		}
 
@@ -358,6 +361,7 @@ public class AutomatedSuite extends DebugSuite {
 		addTest(new TestSuite(HitCountBreakpointsTests.class));
 		addTest(new TestSuite(ThreadFilterBreakpointsTests.class));
 		addTest(new TestSuite(SuspendVMBreakpointsTests.class));
+		addTest(new TestSuite(SuspendVMConditionalBreakpointsTests.class));
 		addTest(new TestSuite(PreLaunchBreakpointTest.class));
 		addTest(new TestSuite(ImportBreakpointsTest.class));
 		addTest(new TestSuite(BreakpointWorkingSetTests.class));
