@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2004, 2015 IBM Corporation and others.
+ * Copyright (c) 2004, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -14,13 +14,14 @@
 package org.eclipse.jdt.internal.debug.ui;
 
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.List;
 
 import org.eclipse.core.commands.AbstractHandler;
 import org.eclipse.core.commands.ExecutionEvent;
 import org.eclipse.core.commands.ExecutionException;
 import org.eclipse.core.commands.IHandler;
+import org.eclipse.core.resources.IProject;
+import org.eclipse.core.resources.ResourcesPlugin;
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.NullProgressMonitor;
@@ -46,6 +47,7 @@ import org.eclipse.jdt.ui.JavaUI;
 import org.eclipse.jdt.ui.text.IJavaPartitions;
 import org.eclipse.jdt.ui.text.JavaTextTools;
 import org.eclipse.jface.dialogs.IDialogConstants;
+import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.dialogs.StatusDialog;
 import org.eclipse.jface.text.Document;
 import org.eclipse.jface.text.DocumentEvent;
@@ -92,10 +94,10 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 
 		public AttributesContentProvider(String[][] variables) {
 			fVariables= new ArrayList<>();
-			for (int i= 0; i < variables.length; i++) {
+			for (String[] v : variables) {
 				String[] variable= new String[2];
-				variable[0]= variables[i][0];
-				variable[1]= variables[i][1];
+				variable[0] = v[0];
+				variable[1] = v[1];
 				fVariables.add(variable);
 			}
 		}
@@ -151,8 +153,7 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 		 * @param list the list
 		 */
 		public void up(List<String[]> list) {
-			for (Iterator<String[]> iter= list.iterator(); iter.hasNext();) {
-				String[] variable= iter.next();
+			for (String[] variable : list) {
 				int index= fVariables.indexOf(variable);
 				fVariables.remove(variable);
 				fVariables.add(index - 1, variable);
@@ -164,8 +165,7 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 		 * @param list the list
 		 */
 		public void down(List<String[]> list) {
-			for (Iterator<String[]> iter= list.iterator(); iter.hasNext();) {
-				String[] variable= iter.next();
+			for (String[] variable : list) {
 				int index= fVariables.indexOf(variable);
 				fVariables.remove(variable);
 				fVariables.add(index + 1, variable);
@@ -174,7 +174,7 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 
 	}
 
-	public class AttributesLabelProvider extends LabelProvider {
+	public static class AttributesLabelProvider extends LabelProvider {
 		@Override
 		public String getText(Object element) {
 			return ((String[])element)[0];
@@ -439,11 +439,10 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 		IStructuredSelection selection= (IStructuredSelection)fAttributeListViewer.getSelection();
 		if (selection.size() > 0) {
 			List<String[]> selectedElements= selection.toList();
-			Object[] elements= fAttributesContentProvider.getElements();
 			Object newSelectedElement= null;
-			for (int i= 0; i < elements.length; i++) {
-				if (!selectedElements.contains(elements[i])) {
-					newSelectedElement= elements[i];
+			for (Object element : fAttributesContentProvider.getElements()) {
+				if (!selectedElements.contains(element)) {
+					newSelectedElement = element;
 				} else {
 					break;
 				}
@@ -499,19 +498,17 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 			// recreate the attribute list
 			fValueTmp= fSnippetDocument.get();
 			createAttributeListWidgets();
-		} else if (isValue) {
+		} else {
 			// dispose the attribute list
 			saveAttributeValue();
-			Control[] children= fAttributesContainer.getChildren();
-			for (int i= 0; i < children.length; i++) {
-				children[i].dispose();
+			for (Control child : fAttributesContainer.getChildren()) {
+				child.dispose();
 			}
 		}
 
 		// dispose and recreate the code snippet editor group
-		Control[] children= fCodeGroup.getChildren();
-		for (int i = 0; i < children.length; i++) {
-			children[i].dispose();
+		for (Control child : fCodeGroup.getChildren()) {
+			child.dispose();
 		}
 		fSnippetViewer.dispose();
 		createCodeGroupWidgets(isValue);
@@ -595,8 +592,8 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 			} else if (oneElementSelected && fSnippetDocument.get().trim().length() == 0) {
 				status.setError(DebugUIMessages.EditLogicalStructureDialog_21);
 			} else {
-				for (int i= 0; i < elements.length; i++) {
-					String[] variable= (String[]) elements[i];
+				for (Object element : elements) {
+					String[] variable = (String[]) element;
 					if (variable[0].trim().length() == 0) {
 						status.setError(DebugUIMessages.EditLogicalStructureDialog_22);
 						break;
@@ -622,7 +619,24 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 	 * Open the 'select type' dialog, and set the user choice into the formatter.
 	 */
 	private void selectType() {
-		Shell shell= getShell();
+		Shell shell = getShell();
+		IProject[] projects = ResourcesPlugin.getWorkspace().getRoot().getProjects();
+		if (projects.length == 0) {
+			MessageDialog.openInformation(shell, DebugUIMessages.DetailFormatterDialog_Select_type_9, DebugUIMessages.DetailFormatterDialog_Select_type_10);
+			return;
+		}
+		boolean allClosed = true;
+		for (IProject iProject : projects) {
+			if (iProject.isOpen()) {
+				allClosed = false;
+				break;
+			}
+		}
+
+		if (allClosed) {
+			MessageDialog.openInformation(shell, DebugUIMessages.DetailFormatterDialog_Select_type_9, DebugUIMessages.DetailFormatterDialog_Select_type_10);
+			return;
+		}
 		SelectionDialog dialog= null;
 		try {
 			dialog= JavaUI.createTypeDialog(shell, PlatformUI.getWorkbench().getProgressService(),
@@ -726,6 +740,9 @@ public class EditLogicalStructureDialog extends StatusDialog implements Listener
 
 		SearchEngine engine= new SearchEngine(JavaCore.getWorkingCopies(null));
 		SearchPattern searchPattern = SearchPattern.createPattern(pattern, IJavaSearchConstants.TYPE, IJavaSearchConstants.DECLARATIONS, SearchPattern.R_EXACT_MATCH | SearchPattern.R_CASE_SENSITIVE);
+		if (searchPattern == null) {
+			return;
+		}
 		IJavaSearchScope scope= SearchEngine.createWorkspaceScope();
 		SearchParticipant[] participants = new SearchParticipant[] {SearchEngine.getDefaultSearchParticipant()};
 		try {
