@@ -311,7 +311,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 			typeName = s.substring(0, typeName.indexOf(".java")); //$NON-NLS-1$
 			String lineNumber = s.substring(index + 1, s.length());
 			lineNumber = lineNumber.trim();
-			int line = (Integer.valueOf(lineNumber)).intValue();
+			int line = Integer.parseInt(lineNumber);
 			getTypeMatches(typeName, matches);
 			return line;
 		}
@@ -326,7 +326,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 			typeName = typeName.trim();
 			String lineNumber = s.substring(index + 1, s.length());
 			lineNumber = lineNumber.trim();
-			int line = (Integer.valueOf(lineNumber)).intValue();
+			int line = Integer.parseInt(lineNumber);
 			getTypeMatches(typeName, matches);
 			return line;
 		}
@@ -336,7 +336,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 			String typeLine = s.substring(index1 + 1, index2).trim();
 			int index = typeLine.indexOf(':');
 			String lineNumber = typeLine.substring(index + 1, typeLine.length()).trim();
-			int line = (Integer.valueOf(lineNumber)).intValue();
+			int line = Integer.parseInt(lineNumber);
 
 			Pattern pattern = Pattern.compile(STACK_TRACE_QUALIFIED_LINE_PATTERN);
 			Matcher matcher = pattern.matcher(s);
@@ -361,7 +361,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 			String method = s.substring(0, index + 1);
 			index = s.indexOf(':');
 			String lineNumber = s.substring(index + 1).trim();
-			int line = (Integer.valueOf(lineNumber)).intValue();
+			int line = Integer.parseInt(lineNumber);
 			getMethodMatches(method, matches);
 			return line;
 		}
@@ -466,6 +466,11 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 	 * @throws InterruptedException if canceled by the user
 	 */
 	private static void handleMatches(List<Object> matches, int line, String inputText) {
+		handleMatches(matches, line, inputText, ActionMessages.OpenFromClipboardAction_OpenFromClipboard);
+	}
+
+	public static void handleMatches(List<Object> matches, int line, String inputText, String title) {
+
 		if (matches.size() > 1) {
 			int flags = JavaElementLabelProvider.SHOW_DEFAULT | JavaElementLabelProvider.SHOW_QUALIFIED | JavaElementLabelProvider.SHOW_ROOT;
 			IWorkbenchWindow window = JDIDebugUIPlugin.getActiveWorkbenchWindow();
@@ -480,7 +485,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 					return DialogSettings.getOrCreateSection(settings, "OpenFromClipboardAction_dialogBounds"); //$NON-NLS-1$
 				}
 			};
-			dialog.setTitle(ActionMessages.OpenFromClipboardAction_OpenFromClipboard);
+			dialog.setTitle(title);
 			dialog.setMessage(ActionMessages.OpenFromClipboardAction_SelectOrEnterTheElementToOpen);
 			dialog.setElements(matches.toArray());
 			dialog.setMultipleSelection(true);
@@ -496,7 +501,7 @@ public class OpenFromClipboardAction implements IWorkbenchWindowActionDelegate {
 			}
 		} else if (matches.size() == 1) {
 			openJavaElements(matches.toArray(), line);
-		} else if (matches.size() == 0) {
+		} else if (matches.isEmpty()) {
 			openInputEditDialog(inputText);
 		}
 	}
