@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2019 IBM Corporation and others.
+ * Copyright (c) 2000, 2021 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -19,6 +19,7 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Optional;
 import java.util.concurrent.atomic.AtomicReference;
 
 import org.eclipse.core.resources.IFile;
@@ -59,6 +60,7 @@ import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.core.JavaModelException;
 import org.eclipse.jdt.core.Signature;
 import org.eclipse.jdt.core.SourceRange;
+import org.eclipse.jdt.core.WorkingCopyOwner;
 import org.eclipse.jdt.core.dom.ASTNode;
 import org.eclipse.jdt.core.dom.ClassInstanceCreation;
 import org.eclipse.jdt.core.dom.CompilationUnit;
@@ -80,13 +82,14 @@ import org.eclipse.jdt.internal.corext.template.java.CompilationUnitContext;
 import org.eclipse.jdt.internal.corext.template.java.CompilationUnitContextType;
 import org.eclipse.jdt.internal.corext.template.java.JavaContextType;
 import org.eclipse.jdt.internal.debug.core.JavaDebugUtils;
+import org.eclipse.jdt.internal.debug.core.breakpoints.FirstLambdaLocationLocator;
 import org.eclipse.jdt.internal.debug.core.breakpoints.ValidBreakpointLocationLocator;
 import org.eclipse.jdt.internal.debug.ui.BreakpointUtils;
 import org.eclipse.jdt.internal.debug.ui.DebugWorkingCopyManager;
 import org.eclipse.jdt.internal.debug.ui.IJDIPreferencesConstants;
 import org.eclipse.jdt.internal.debug.ui.JDIDebugUIPlugin;
 import org.eclipse.jdt.internal.ui.JavaPlugin;
-import org.eclipse.jdt.internal.ui.javaeditor.CompilationUnitEditor;
+import org.eclipse.jdt.internal.ui.javaeditor.JavaEditor;
 import org.eclipse.jdt.internal.ui.text.template.contentassist.TemplateEngine;
 import org.eclipse.jdt.internal.ui.text.template.contentassist.TemplateProposal;
 import org.eclipse.jdt.ui.IWorkingCopyManager;
@@ -100,6 +103,7 @@ import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.ITextSelection;
 import org.eclipse.jface.text.ITextViewer;
 import org.eclipse.jface.text.Position;
+import org.eclipse.jface.text.TextSelection;
 import org.eclipse.jface.text.source.Annotation;
 import org.eclipse.jface.text.source.IAnnotationModel;
 import org.eclipse.jface.text.source.IVerticalRulerInfo;
@@ -244,6 +248,123 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
         job.schedule();
     }
 
+	public void toggleLambdaMethodBreakpoints(final IWorkbenchPart part, final ISelection finalSelection, final ValidBreakpointLocationLocator loc) {
+		Job job = new Job("Toggle Lambda Method Breakpoints") { //$NON-NLS-1$
+			@Override
+			protected IStatus run(IProgressMonitor monitor) {
+				if (monitor.isCanceled()) {
+					return Status.CANCEL_STATUS;
+				}
+				try {
+					return doToggleLambdaMethodBreakpoints(part, finalSelection, loc, monitor);
+				} catch (CoreException e) {
+					return e.getStatus();
+				} finally {
+					BreakpointToggleUtils.setUnsetTracepoints(false);
+				}
+			}
+		};
+		job.setPriority(Job.INTERACTIVE);
+		job.setSystem(true);
+		job.schedule();
+	}
+
+	public void toggleLambdaEntryMethodBreakpoints(final IWorkbenchPart part, final ISelection finalSelection, final String lambdaMethodName, final String lambdaMethodSignature) {
+		Job job = new Job("Toggle Lambda Entry Method Breakpoints") { //$NON-NLS-1$
+			@Override
+			protected IStatus run(IProgressMonitor monitor) {
+				if (monitor.isCanceled()) {
+					return Status.CANCEL_STATUS;
+				}
+				try {
+					return doToggleLambdaEntryMethodBreakpoints(part, finalSelection, lambdaMethodName, lambdaMethodSignature, monitor);
+				} catch (CoreException e) {
+					return e.getStatus();
+				} finally {
+					BreakpointToggleUtils.setUnsetTracepoints(false);
+				}
+			}
+		};
+		job.setPriority(Job.INTERACTIVE);
+		job.setSystem(true);
+		job.schedule();
+	}
+
+	static IStatus doToggleLambdaEntryMethodBreakpoints(IWorkbenchPart part, ISelection selection, String lambdaMethodName, String lambdaMethodSignature, IProgressMonitor monitor) throws CoreException {
+		ITextEditor textEditor = getTextEditor(part);
+		if (textEditor == null || !(selection instanceof ITextSelection)) {
+			return Status.OK_STATUS;
+		}
+		ITextSelection textSelection = (ITextSelection) selection;
+		IEditorInput editorInput = textEditor.getEditorInput();
+		ITypeRoot root = getTypeRoot(editorInput);
+		if (root instanceof ICompilationUnit) {
+			ICompilationUnit unit = (ICompilationUnit) root;
+			synchronized (unit) {
+				unit.reconcile(ICompilationUnit.NO_AST, false, null, null);
+			}
+			IJavaElement[] elements = unit.codeSelect(textSelection.getOffset(), textSelection.getLength());
+			if (elements == null || elements.length == 0) {
+				BreakpointToggleUtils.report(ActionMessages.LambdaEntryBreakpointToggleAction_Unavailable, part);
+				return Status.OK_STATUS;
+			}
+			IMethod method = null;
+			if (elements[0] instanceof IMethod) {
+				method = (IMethod) elements[0];
+			} else if (elements[0].getParent() instanceof IMethod) {
+				method = (IMethod) elements[0].getParent();
+			}
+
+			if (method != null) {
+				doToggleMethodBreakpoint(method, lambdaMethodName, lambdaMethodSignature, part, selection, monitor);
+			} else {
+				BreakpointToggleUtils.report(ActionMessages.LambdaEntryBreakpointToggleAction_Unavailable, part);
+			}
+		}
+		return Status.OK_STATUS;
+	}
+
+
+	static IStatus doToggleLambdaMethodBreakpoints(IWorkbenchPart part, ISelection selection, ValidBreakpointLocationLocator loc, IProgressMonitor monitor) throws CoreException {
+		ITextEditor textEditor = getTextEditor(part);
+		if (textEditor == null || !(selection instanceof ITextSelection)) {
+			return Status.OK_STATUS;
+		}
+		ITextSelection textSelection = (ITextSelection) selection;
+		IEditorInput editorInput = textEditor.getEditorInput();
+		ITypeRoot root = getTypeRoot(editorInput);
+		if (root instanceof ICompilationUnit) {
+			ICompilationUnit unit = (ICompilationUnit) root;
+			synchronized (unit) {
+				unit.reconcile(ICompilationUnit.NO_AST, false, null, null);
+			}
+			IJavaElement[] elements = unit.codeSelect(textSelection.getOffset(), textSelection.getLength());
+			if (elements == null || elements.length == 0) {
+				ValidBreakpointLocationLocator locNew = new ValidBreakpointLocationLocator(loc.getCompilationUnit(), textSelection.getStartLine()
+						+ 1, true, true);
+				locNew.getCompilationUnit().accept(locNew);
+				toggleLineBreakpoints(part, selection, false, locNew);
+				return Status.OK_STATUS;
+			}
+			IMethod method = null;
+			if (elements[0] instanceof IMethod) {
+				method = (IMethod) elements[0];
+			} else if (elements[0].getParent() instanceof IMethod) {
+				method = (IMethod) elements[0].getParent();
+			}
+
+			if (method != null) {
+				doToggleMethodBreakpoint(method, loc.getLambdaMethodName(), loc.getfLambdaMethodSignature(), part, selection, monitor);
+			} else {
+				ValidBreakpointLocationLocator locNew = new ValidBreakpointLocationLocator(loc.getCompilationUnit(), textSelection.getStartLine()
+						+ 1, true, true);
+				locNew.getCompilationUnit().accept(locNew);
+				toggleLineBreakpoints(part, selection, false, locNew);
+			}
+
+		}
+		return Status.OK_STATUS;
+	}
 	static IStatus doToggleMethodBreakpoints(IWorkbenchPart part, ISelection finalSelection, IProgressMonitor monitor) throws CoreException {
 		BreakpointToggleUtils.report(null, part);
 		ISelection selection = finalSelection;
@@ -271,6 +392,10 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 	}
 
 	private static void doToggleMethodBreakpoint(IMethod member, IWorkbenchPart part, ISelection finalSelection, IProgressMonitor monitor) throws CoreException {
+		doToggleMethodBreakpoint(member, null, null, part, finalSelection, monitor);
+	}
+
+	private static void doToggleMethodBreakpoint(IMethod member, String lambdaMethodName, String lambdaMethodSignature, IWorkbenchPart part, ISelection finalSelection, IProgressMonitor monitor) throws CoreException {
 		IJavaBreakpoint breakpoint = getMethodBreakpoint(member);
 		if (breakpoint != null) {
 			if (BreakpointToggleUtils.isToggleTracepoints()) {
@@ -291,15 +416,15 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 		Map<String, Object> attributes = new HashMap<>(10);
 		BreakpointUtils.addJavaBreakpointAttributes(attributes, member);
 		IType type = member.getDeclaringType();
-		String signature = member.getSignature();
-		String mname = member.getElementName();
+		String mname = Optional.ofNullable(lambdaMethodName).orElse(member.getElementName());
+		String signature = Optional.ofNullable(lambdaMethodSignature).orElse(member.getSignature());
 		if (member.isConstructor()) {
 			mname = "<init>"; //$NON-NLS-1$
 			if (type.isEnum()) {
 				signature = "(Ljava.lang.String;I" + signature.substring(1); //$NON-NLS-1$
 			}
 		}
-		if (!type.isBinary()) {
+		if (!type.isBinary() && lambdaMethodName == null) {
 			signature = resolveMethodSignature(member);
 			if (signature == null) {
 				BreakpointToggleUtils.report(ActionMessages.ManageMethodBreakpointActionDelegate_methodNonAvailable, part);
@@ -309,8 +434,8 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 		IResource resource = BreakpointUtils.getBreakpointResource(member);
 		String qualifiedName = getQualifiedName(type);
 		IJavaMethodBreakpoint methodBreakpoint = JDIDebugModel.createMethodBreakpoint(resource, qualifiedName, mname, signature, true, false, false, -1, start, end, 0, true, attributes);
-		if (BreakpointToggleUtils.isToggleTracepoints() && finalSelection instanceof ITextSelection && part instanceof CompilationUnitEditor) {
-			String pattern = getCodeTemplate((ITextSelection) finalSelection, (CompilationUnitEditor) part);
+		if (BreakpointToggleUtils.isToggleTracepoints() && finalSelection instanceof ITextSelection && part instanceof JavaEditor) {
+			String pattern = getCodeTemplate((ITextSelection) finalSelection, (JavaEditor) part);
 			if (pattern != null) {
 				pattern = pattern.trim();
 				pattern = pattern.replaceAll("\\\t", ""); //$NON-NLS-1$//$NON-NLS-2$
@@ -409,8 +534,8 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 			}
 			BreakpointUtils.addJavaBreakpointAttributes(attributes, type);
 			IJavaLineBreakpoint breakpoint = JDIDebugModel.createLineBreakpoint(resource, tname, lnumber, charstart, charend, 0, true, attributes);
-			if (BreakpointToggleUtils.isToggleTracepoints() && selection instanceof ITextSelection && part instanceof CompilationUnitEditor) {
-				String pattern = getCodeTemplate((ITextSelection) selection, (CompilationUnitEditor) part);
+			if (BreakpointToggleUtils.isToggleTracepoints() && selection instanceof ITextSelection && part instanceof JavaEditor) {
+				String pattern = getCodeTemplate((ITextSelection) selection, (JavaEditor) part);
 				if (pattern != null) {
 					pattern = pattern.trim();
 					pattern = pattern.replaceAll("\\\t", ""); //$NON-NLS-1$//$NON-NLS-2$
@@ -1158,6 +1283,7 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
      * @param element the element to get the breakpoint from
      * @return the current breakpoint from the element or <code>null</code>
      */
+	@SuppressWarnings("restriction")
 	protected static IJavaBreakpoint getMethodBreakpoint(IMember element) {
         IBreakpointManager breakpointManager = DebugPlugin.getDefault().getBreakpointManager();
         IBreakpoint[] breakpoints = breakpointManager.getBreakpoints(JDIDebugModel.getPluginIdentifier());
@@ -1189,6 +1315,9 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 				}
 			} else {
 				if (container instanceof IMethod) {
+					if (method instanceof org.eclipse.jdt.internal.core.LambdaMethod) {
+						return null;
+					}
 					if (method.getDeclaringType().getFullyQualifiedName().equals(container.getDeclaringType().getFullyQualifiedName())) {
 						if (method.isSimilar((IMethod) container)) {
 							return methodBreakpoint;
@@ -1282,6 +1411,15 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 			if (e instanceof IMember) {
 				m = (IMember) e;
 			}
+			// Class breakpoint should be created if the offset was at the record component in the record definition
+			if (m != null && m.getParent() instanceof IType && ((IType) m.getParent()).isRecord()) {
+				if (m instanceof IField) {
+					IField field = (IField)m;
+					if (field.isRecordComponent()) {
+						m = (IMember) field.getParent();
+					}
+				}
+			}
 		}
 		if (m != null) {
 			return new StructuredSelection(m);
@@ -1422,9 +1560,21 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 			JDIDebugUIPlugin.log("Failed to parse CU for: " + editor.getTitle(), new IllegalStateException()); //$NON-NLS-1$
 			return;
 		}
-		ValidBreakpointLocationLocator loc = new ValidBreakpointLocationLocator(unit, ts.getStartLine() + 1, true, true);
+		ValidBreakpointLocationLocator loc = null;
+		boolean lambdaEntryBP = false;
+		if (BreakpointToggleUtils.isToggleLambdaEntryBreakpoint()) {
+			loc = new ValidBreakpointLocationLocator(unit, ts.getStartLine()
+				+ 1, true, true, ts.getOffset(), ts.getLength());
+			lambdaEntryBP = true;
+			BreakpointToggleUtils.setUnsetLambdaEntryBreakpoint(false);
+		} else {
+			loc = new ValidBreakpointLocationLocator(unit, ts.getStartLine() + 1, true, true, ts.getOffset(), ts.getLength());
+		}
 		unit.accept(loc);
-		if (loc.getLocationType() == ValidBreakpointLocationLocator.LOCATION_METHOD) {
+
+		if (loc.getLocationType() == ValidBreakpointLocationLocator.LOCATION_LAMBDA_METHOD) {
+			toggleLambdaMethodBreakpoints(part, ts, loc);
+		} else if (loc.getLocationType() == ValidBreakpointLocationLocator.LOCATION_METHOD) {
 			toggleMethodBreakpoints(part, ts);
 		} else if (loc.getLocationType() == ValidBreakpointLocationLocator.LOCATION_FIELD) {
 			if (BreakpointToggleUtils.isToggleTracepoints()) {
@@ -1434,7 +1584,31 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 			}
 			toggleWatchpoints(part, ts);
 		} else if (loc.getLocationType() == ValidBreakpointLocationLocator.LOCATION_LINE) {
-			toggleLineBreakpoints(part, ts, false, loc);
+			if (lambdaEntryBP) {
+				IEditorInput editorInput = editor.getEditorInput();
+				IDocumentProvider documentProvider = editor.getDocumentProvider();
+				if (documentProvider == null) {
+					BreakpointToggleUtils.report(ActionMessages.LambdaEntryBreakpointToggleAction_Unavailable, part);
+					throw new CoreException(Status.CANCEL_STATUS);
+				}
+				IDocument document = documentProvider.getDocument(editorInput);
+				try {
+					IRegion region = document.getLineInformation(ts.getStartLine());
+					FirstLambdaLocationLocator firstLambda = new FirstLambdaLocationLocator(region.getOffset(), region.getOffset() + region.getLength());
+					unit.accept(firstLambda);
+					if (firstLambda.getNodeLength() == -1 || firstLambda.getNodeOffset() == -1) {
+						BreakpointToggleUtils.report(ActionMessages.LambdaEntryBreakpointToggleAction_Unavailable, part);
+						return;
+					}
+					ITextSelection textSelection = new TextSelection(document, firstLambda.getNodeOffset(), firstLambda.getNodeLength());
+					toggleLambdaEntryMethodBreakpoints(part, textSelection, firstLambda.getLambdaMethodName(), firstLambda.getfLambdaMethodSignature());
+				} catch (BadLocationException e) {
+					BreakpointToggleUtils.report(ActionMessages.LambdaEntryBreakpointToggleAction_Unavailable, part);
+				}
+
+			} else {
+				toggleLineBreakpoints(part, ts, false, loc);
+			}
 		}
 	}
 
@@ -1585,7 +1759,7 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 	 * @return the type root or <code>null</code> if one cannot be derived
 	 * @since 3.8
 	 */
-	private static String getCodeTemplate(ITextSelection textSelection, CompilationUnitEditor part) {
+	private static String getCodeTemplate(ITextSelection textSelection, JavaEditor part) {
 		ITextViewer viewer = part.getViewer();
 		if (viewer == null) {
 			return null;
@@ -1596,29 +1770,26 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 		return templateBuffer.get();
 	}
 
-	private static void doGetCodeTemplate(ITextSelection textSelection, CompilationUnitEditor part, ITextViewer viewer, TemplateContextType contextType, AtomicReference<String> templateBuffer) {
+	private static void doGetCodeTemplate(ITextSelection textSelection, JavaEditor part, ITextViewer viewer, TemplateContextType contextType, AtomicReference<String> templateBuffer) {
 		ITextEditor editor = getTextEditor(part);
 		if (editor == null) {
 			return;
 		}
-		TemplateEngine statementEngine = new TemplateEngine(contextType);
-		statementEngine.reset();
-		IJavaElement element = getJavaElement(editor.getEditorInput());
-		ICompilationUnit cunit = null;
-		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
-		IFile file = root.getFile(element.getPath());
-		cunit = JavaCore.createCompilationUnitFrom(file);
 		IDocumentProvider documentProvider = editor.getDocumentProvider();
 		if (documentProvider == null) {
 			return;
 		}
+		ICompilationUnit cunit = getCompilationUnit(editor);
+		if (cunit == null) {
+			return;
+		}
+		TemplateEngine statementEngine = new TemplateEngine(contextType);
+		statementEngine.reset();
 		IDocument document = documentProvider.getDocument(editor.getEditorInput());
 		try {
 			IRegion line = document.getLineInformation(textSelection.getStartLine() + 1);
-			Point selectedRange = viewer.getSelectedRange();
-			viewer.setSelectedRange(selectedRange.x, 0);
+			Point selectedRange = new Point(textSelection.getOffset(), textSelection.getLength());
 			statementEngine.complete(viewer, selectedRange, line.getOffset(), cunit);
-			viewer.setSelectedRange(selectedRange.x, selectedRange.y);
 			TemplateProposal[] templateProposals = statementEngine.getResults();
 			for (TemplateProposal templateProposal : templateProposals) {
 				Template template = templateProposal.getTemplate();
@@ -1636,4 +1807,22 @@ public class ToggleBreakpointAdapter implements IToggleBreakpointsTargetExtensio
 		}
 	}
 
+	private static ICompilationUnit getCompilationUnit(ITextEditor editor) {
+		IJavaElement element = getJavaElement(editor.getEditorInput());
+		if (element == null) {
+			return null;
+		}
+		if (element instanceof IOrdinaryClassFile) {
+			try {
+				return ((IOrdinaryClassFile) element).getWorkingCopy(new WorkingCopyOwner() {}, null);
+			} catch (JavaModelException e) {
+				// ignore
+				return null;
+			}
+		}
+		IWorkspaceRoot root = ResourcesPlugin.getWorkspace().getRoot();
+		IFile file = root.getFile(element.getPath());
+		return JavaCore.createCompilationUnitFrom(file);
+	}
+
 }
