@@ -46,6 +46,8 @@ import org.eclipse.jdt.internal.debug.ui.IJDIPreferencesConstants;
 import org.eclipse.jdt.internal.debug.ui.JDIDebugUIPlugin;
 import org.eclipse.jdt.internal.debug.ui.JDIModelPresentation;
 import org.eclipse.jface.viewers.TreePath;
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.graphics.FontData;
 
 /**
  * Base implementation of a label provider for Java variables
@@ -103,6 +105,23 @@ public class JavaVariableLabelProvider extends VariableLabelProvider implements
 		return typeName;
 	}
 
+	@Override
+	protected FontData getFontData(TreePath elementPath, IPresentationContext presentationContext, String columnId) throws CoreException {
+		var result = super.getFontData(elementPath, presentationContext, columnId);
+		if (result == null) {
+			return result;
+		}
+		var element = elementPath.getLastSegment();
+		if (element instanceof IJavaVariable) {
+			var variable = (IJavaVariable) element;
+			var value = variable.getValue();
+			if (value instanceof IJavaObject && ((IJavaObject) value).getLabel() != null) {
+				return new FontData(result.getName(), result.getHeight(), result.getStyle() ^ SWT.BOLD);
+			}
+		}
+		return result;
+	}
+
 	/* (non-Javadoc)
 	 * @see org.eclipse.debug.internal.ui.elements.adapters.VariableLabelAdapter#getVariableTypeName(org.eclipse.debug.core.model.IVariable)
 	 */
@@ -172,6 +191,15 @@ public class JavaVariableLabelProvider extends VariableLabelProvider implements
 			}
 			return ""; //$NON-NLS-1$
 		}
+		if (JavaVariableColumnPresentation.COLUMN_LABEL.equals(columnId)) {
+			if (value instanceof IJavaObject) {
+				String label = ((IJavaObject) value).getLabel();
+				if (label != null) {
+					return label;
+				}
+			}
+			return ""; //$NON-NLS-1$
+		}
 		return super.getColumnText(variable, value, context, columnId);
 	}
 
@@ -192,16 +220,12 @@ public class JavaVariableLabelProvider extends VariableLabelProvider implements
 	 * @param value preference value for PREF_SHOW_DETAILS
 	 */
 	private void determineSerializationMode(String value) {
-		switch (value) {
-			case IJDIPreferencesConstants.INLINE_ALL:
-				fSerializeMode = SERIALIZE_NONE;
-				break;
-			case IJDIPreferencesConstants.INLINE_FORMATTERS:
-				fSerializeMode = SERIALIZE_SOME;
-				break;
-			default:
-				fSerializeMode = SERIALIZE_ALL;
-				break;
+		if (IJDIPreferencesConstants.INLINE_ALL.equals(value)) {
+			fSerializeMode = SERIALIZE_NONE;
+		} else if (IJDIPreferencesConstants.INLINE_FORMATTERS.equals(value)) {
+			fSerializeMode = SERIALIZE_SOME;
+		} else {
+			fSerializeMode = SERIALIZE_ALL;
 		}
 	}
 
