@@ -14,6 +14,12 @@
  *******************************************************************************/
 package org.eclipse.jdt.internal.debug.core.logicalstructures;
 
+import java.text.MessageFormat;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.Map;
+import java.util.stream.Collectors;
+
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IConfigurationElement;
 import org.eclipse.core.runtime.IStatus;
@@ -24,9 +30,11 @@ import org.eclipse.debug.core.DebugPlugin;
 import org.eclipse.debug.core.ILogicalStructureType;
 import org.eclipse.debug.core.IStatusHandler;
 import org.eclipse.debug.core.model.IDebugTarget;
+import org.eclipse.debug.core.model.ILogicalStructureTypeDelegate3;
 import org.eclipse.debug.core.model.IThread;
 import org.eclipse.debug.core.model.IValue;
 import org.eclipse.jdt.core.IJavaProject;
+import org.eclipse.jdt.core.JavaCore;
 import org.eclipse.jdt.debug.core.IJavaClassType;
 import org.eclipse.jdt.debug.core.IJavaDebugTarget;
 import org.eclipse.jdt.debug.core.IJavaInterfaceType;
@@ -36,18 +44,19 @@ import org.eclipse.jdt.debug.core.IJavaStackFrame;
 import org.eclipse.jdt.debug.core.IJavaThread;
 import org.eclipse.jdt.debug.core.IJavaType;
 import org.eclipse.jdt.debug.core.IJavaValue;
-import org.eclipse.jdt.debug.core.IJavaVariable;
 import org.eclipse.jdt.debug.eval.IAstEvaluationEngine;
 import org.eclipse.jdt.debug.eval.ICompiledExpression;
 import org.eclipse.jdt.debug.eval.IEvaluationListener;
 import org.eclipse.jdt.debug.eval.IEvaluationResult;
+import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.debug.core.JDIDebugPlugin;
 import org.eclipse.jdt.internal.debug.core.JavaDebugUtils;
 import org.eclipse.jdt.internal.debug.core.model.JDIValue;
 
-import com.ibm.icu.text.MessageFormat;
+import com.sun.jdi.VMDisconnectedException;
 
-public class JavaLogicalStructure implements ILogicalStructureType {
+
+public class JavaLogicalStructure implements ILogicalStructureType, ILogicalStructureTypeDelegate3 {
 
 	private static IStatusHandler fgStackFrameProvider;
 
@@ -130,8 +139,10 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 		 * @throws DebugException
 		 */
 		public IJavaValue evaluate(String snippet) throws DebugException {
+			Map<String, String> compileOptions =
+					Collections.singletonMap(CompilerOptions.OPTION_JdtDebugCompileMode, JavaCore.ENABLED);
 			ICompiledExpression compiledExpression = fEvaluationEngine
-					.getCompiledExpression(snippet, fEvaluationType);
+					.getCompiledExpression(snippet, fEvaluationType, compileOptions);
 			if (compiledExpression.hasErrors()) {
 				String[] errorMessages = compiledExpression.getErrorMessages();
 				log(errorMessages);
@@ -141,7 +152,7 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 			fResult = null;
 			fEvaluationEngine.evaluateExpression(compiledExpression,
 					fEvaluationValue, fThread, this,
-					DebugEvent.EVALUATION_IMPLICIT, false);
+					DebugEvent.EVALUATION_IMPLICIT | IAstEvaluationEngine.DISABLE_GC_ON_RESULT, false);
 			synchronized (this) {
 				if (fResult == null) {
 					try {
@@ -182,13 +193,10 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 		 */
 		private void log(String[] messages) {
 			if (isContributed()) {
-				StringBuilder log = new StringBuilder();
-				for (String message : messages) {
-					log.append(message).append('\n');
-				}
-				JDIDebugPlugin.log(new Status(IStatus.ERROR, JDIDebugPlugin
-						.getUniqueIdentifier(), IStatus.ERROR, log.toString(),
-						null));
+				String log = Arrays.asList(messages).stream().collect(Collectors.joining("\n")); //$NON-NLS-1$
+				String error = String.format("Error while evaluating '%s' logical structure for type %s with the value '%s'", //$NON-NLS-1$
+						getDescription(), getQualifiedTypeName(), getValue());
+				JDIDebugPlugin.log(new Status(IStatus.ERROR, JDIDebugPlugin.getUniqueIdentifier(), IStatus.ERROR, error, new IllegalStateException(log)));
 			}
 		}
 	}
@@ -216,8 +224,7 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 					JDIDebugPlugin.getUniqueIdentifier(), JDIDebugPlugin.ERROR,
 					LogicalStructuresMessages.JavaLogicalStructures_0, null));
 		}
-		fSubtypes = Boolean.valueOf(
-				configurationElement.getAttribute("subtypes")).booleanValue(); //$NON-NLS-1$
+		fSubtypes = Boolean.parseBoolean(configurationElement.getAttribute("subtypes")); //$NON-NLS-1$
 		fValue = configurationElement.getAttribute("value"); //$NON-NLS-1$
 		fDescription = configurationElement.getAttribute("description"); //$NON-NLS-1$
 		if (fDescription == null) {
@@ -303,7 +310,7 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 					evaluationEngine);
 			if (fValue == null) {
 				// evaluate each variable
-				IJavaVariable[] variables = new IJavaVariable[fVariables.length];
+				JDIPlaceholderVariable[] variables = new JDIPlaceholderVariable[fVariables.length];
 				for (int i = 0; i < fVariables.length; i++) {
 					variables[i] = new JDIPlaceholderVariable(fVariables[i][0],
 							evaluationBlock.evaluate(fVariables[i][1]),
@@ -327,6 +334,20 @@ public class JavaLogicalStructure implements ILogicalStructureType {
 		return value;
 	}
 
+	@Override
+	public void releaseValue(IValue value) {
+		if (value instanceof IJavaObject) {
+			try {
+				((IJavaObject) value).enableCollection();
+			} catch (DebugException e) {
+				if (!(e.getStatus().getException() instanceof VMDisconnectedException)) {
+					// don't worry about GC if the VM has terminated
+					JDIDebugPlugin.log(e);
+				}
+			}
+		}
+	}
+
 	/**
 	 * Returns the <code>IJavaReferenceType</code> from the specified
 	 * <code>IJavaObject</code>
